<template>
    <ele-page flex-table>
        <book-search @search="reload" />

        <common-table
            ref="pageRef"
            :pageConfig="pageConfig"
            :columns="columns"
            :tools="false"
        >
            <template #toolbar>
                <el-radio-group
                    @change="handleStatusChange"
                    v-model="searchType"
                >
                    <el-radio-button
                        label="已加入回收书单（正在回收）"
                        value="1"
                    />
                    <el-radio-button
                        label="已加入回收书单（暂停回收）"
                        value="2"
                    />
                    <el-radio-button label="未加入回收书单" value="3" />
                    <el-radio-button label="黑名单" value="4" />
                    <el-radio-button label="无数据信息" value="5" />
                </el-radio-group>

                <span class="ml-8"></span>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:scanLog:batchRemoveBooklist'"
                    @click="handleOptBooklist('remove')"
                    v-if="['1', '2'].includes(searchType)"
                >
                    移除回收书单
                </el-button>
                <el-button
                    type="success"
                    plain
                    v-permission="'recycle:scanLog:batchAddBooklist'"
                    @click="handleOptBooklist('add')"
                    v-if="['3', '4'].includes(searchType)"
                >
                    加入回收书单
                </el-button>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:scanLog:batchRemoveBlacklist'"
                    @click="handleOptBlacklist('remove')"
                    v-if="searchType === '4'"
                >
                    移除黑名单
                </el-button>
                <el-button
                    type="danger"
                    plain
                    v-permission="'recycle:scanLog:batchAddBlacklist'"
                    @click="handleOptBlacklist('add')"
                    v-if="searchType !== '4'"
                >
                    加黑名单
                </el-button>

                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:scanLog:batchPauseRecycle'"
                    @click="handleOptRecycle('pause')"
                    v-if="searchType === '1'"
                >
                    暂停回收
                </el-button>
                <el-button
                    type="warning"
                    plain
                    v-permission="'recycle:scanLog:batchStartRecycle'"
                    @click="handleOptRecycle('start')"
                    v-if="searchType === '2'"
                >
                    开启回收
                </el-button>

                <el-button
                    type="success"
                    plain
                    v-permission="'recycle:scanLog:batchAddSocial'"
                    @click="handleOptType(1)"
                >
                    加社科库
                </el-button>
                <el-button
                    type="primary"
                    plain
                    v-permission="'recycle:scanLog:batchAddTeach'"
                    @click="handleOptType(2)"
                >
                    加教材库
                </el-button>
            </template>

            <template #cover="{ row }">
                <el-image
                    style="width: 90px; height: 120px; border-radius: 4px"
                    fit="cover"
                    :src="row.cover"
                    :preview-src-list="[row.cover]"
                    :initial-index="0"
                    preview-teleported
                />
            </template>
            <template #baseInfo="{ row }">
                <book-info :row="row" @refresh="reload" />
            </template>
            <template #stock="{ row }">
                <book-stock :row="row" />
            </template>

            <template #action="{ row }">
                <el-button
                    type="primary"
                    link
                    v-permission="'recycle:scanLog:viewLog'"
                    @click="handleViewLog(row)"
                >
                    [查看详情]
                </el-button>
                <el-button
                    color="#192bbe"
                    plain
                    link
                    v-permission="'recycle:scanLog:setParams'"
                    @click="handleSetParams(row)"
                >
                    [设置独立参数]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:scanLog:removeBlacklist'"
                    @click="handleOptBlacklist('remove', row)"
                    v-if="row.bookStatus == 3"
                >
                    [移除黑名单]
                </el-button>
                <el-button
                    type="warning"
                    link
                    v-permission="'recycle:scanLog:addBlacklist'"
                    @click="handleOptBlacklist('add', row)"
                    v-if="row.bookStatus == 1 || row.bookStatus == 2"
                >
                    [加入黑名单]
                </el-button>
                <el-button
                    type="danger"
                    link
                    v-permission="'recycle:scanLog:pauseRecycle'"
                    @click="handleOptRecycle('pause', row)"
                    v-if="row.recycleStatus == 1"
                >
                    [暂停回收]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:scanLog:startRecycle'"
                    @click="handleOptRecycle('start', row)"
                    v-else
                >
                    [开启回收]
                </el-button>
                <el-button
                    type="success"
                    link
                    v-permission="'recycle:scanLog:removeBooklist'"
                    @click="handleOptBooklist('remove', row)"
                    v-if="row.bookStatus == 2"
                >
                    [移除回收书单]
                </el-button>
                <el-button
                    type="danger"
                    link
                    v-permission="'recycle:scanLog:addBooklist'"
                    @click="handleOptBooklist('add', row)"
                    v-if="row.bookStatus == 1"
                >
                    [加入回收书单]
                </el-button>
            </template>
        </common-table>

        <set-params ref="paramsRef" />
        <scan-log ref="logRef" />
        <add-discount ref="discountRef" @refresh="reload" />
        <order-blacklist ref="blacklistRef" @refresh="reload" />
    </ele-page>
</template>

<script setup>
    import { ref, reactive } from 'vue';
    import CommonTable from '@/components/CommonPage/CommonTable.vue';
    import bookSearch from '@/views/recycle/components/book-search.vue';
    import bookInfo from '@/views/recycle/components/book-info.vue';
    import bookStock from '@/views/recycle/components/book-stock.vue';
    import setParams from '@/views/recycle/components/set-params.vue';
    import scanLog from './components/scan-log.vue';
    import addDiscount from '@/views/recycle/components/add-discount.vue';
    import orderBlacklist from '@/views/recycleOrder/detail/order-blacklist.vue';
    import { useBookOperation } from '@/utils/use-book-operation';
    import { ElMessage } from 'element-plus';

    defineOptions({ name: 'ScanLoglist' });

    const searchType = ref('1');
    function handleStatusChange(value) {
        searchType.value = value;
        pageConfig.params.searchType = value;
        pageRef.value.reload();
    }

    /** 表格列配置 */
    const columns = ref([
        {
            type: 'selection',
            columnKey: 'selection',
            width: 50,
            align: 'center',
            fixed: 'left'
        },
        {
            label: '图片',
            prop: 'cover',
            width: 120,
            slot: 'cover'
        },
        {
            label: '信息',
            prop: 'baseInfo',
            width: 540,
            slot: 'baseInfo'
        },
        { label: '回收折扣', prop: 'recycleDiscount' },
        { label: '预估金额', prop: 'recyclePrice' },
        {
            label: '扫描次数',
            prop: 'scanNum',
            sortable: true,
            columnKey: '1',
            minWidth: 100,
            formatter: (row) => row?.scanNum || 0
        },
        {
            label: '总回收数量',
            prop: 'recycleTotalNum',
            sortable: true,
            columnKey: '2',
            minWidth: 120
        },
        {
            label: '最后一次扫描时间',
            prop: 'lastScanTime',
            sortable: true,
            columnKey: '3',
            minWidth: 160,
            formatter: (row) => (row?.lastScanTime ? row?.lastScanTime : '-')
        },
        {
            columnKey: 'action',
            label: '操作',
            width: 150,
            slot: 'action',
            fixed: 'right'
        }
    ]);

    /** 页面组件实例 */
    const pageRef = ref(null);

    const pageConfig = reactive({
        pageUrl: '/user/userScanLog/getBookScanLogList',
        fileName: '扫码记录管理',
        cacheKey: 'scanLoglistTable',
        params: {
            searchType: '1'
        },
        rowKey: 'isbn'
    });

    //刷新表格
    function reload(where) {
        pageRef.value?.reload(where);
    }

    // 使用图书操作混入
    const {
        blacklistRef,
        discountRef,
        paramsRef,
        handleOptBooklist,
        handleOptBlacklist,
        handleAddDiscount,
        handleSetParams,
        handleOptType,
        handleOptRecycle
    } = useBookOperation(pageRef);

    //查看详情
    const logRef = ref(null);
    function handleViewLog(row) {
        logRef.value?.handleOpen(row);
    }
</script>
